pub struct CommandRun {
pub reports: Vec<String>,
pub warnings: Vec<String>,
}Expand description
What a command line did, for the front end to finish and report.
Fields
reports: Vec<String>What the commands had to say (set beep? and the like), in
order, for the front end to show as one line.
warnings: Vec<String>Warnings from recompiling the session’s derived state.