ComposeSetup

Struct ComposeSetup 

pub struct ComposeSetup {
    pub kind: ComposeKind,
    pub base: Option<ComposeBase>,
    pub to: Option<String>,
    pub cc: Option<String>,
    pub bcc: Option<String>,
    pub subject_prefill: Option<String>,
    pub subject: Option<String>,
    pub fwd_attach: Option<bool>,
}

Fields

kind: ComposeKindbase: Option<ComposeBase>to: Option<String>cc: Option<String>

mutt’s $askcc / $askbcc, once answered.

bcc: Option<String>subject_prefill: Option<String>

What the Subject prompt will offer, worked out when To was answered and parked while the copies are asked about.

subject: Option<String>

Parked here while the include-original question is up.

fwd_attach: Option<bool>

mime_forward = “ask”: the question’s answer, once given.